<?php
# dvdisaster: Russian homepage dictionary
# Copyright (C) 2007-2009 Igor Gorbounov
#
# UTF-8 trigger: äöüß 

# Russian dictionary for some phrases used in dvdisaster.php

$trans_version="Версия";

$trans_to_internet="К интернет-версии";
$trans_to_hoster="Краткое изложение (на SourceForge.net)";

$trans_back="Назад";
$trans_screen_shot="Снимок с экрана";

$trans_contents="Содержание";
$trans_news="Новости";
$trans_atom_title="dvdisaster news";
$trans_hosting="Размещено на";

$trans_fdl="Дословное копирование и распространение всей этой статьи разрешается на любом носителе, при условии, что это уведомление сохраняется.";
$trans_copyright="Copyright 2007-2009 Igor Gorbounov.";

$trans_sourcecode="Исходные тексты для всех операционных систем:";
$trans_signature="Цифровая подпись:";
$trans_md5="MD5 checksum:";
$trans_macbinary="Двоичная версия для Mac OS X 10.5 / x86:";
$trans_winbinary="Двоичная версия для Windows:";
?>
